// $Id: Exporter.java 13947 2011-10-04 14:26:47Z mike $

package org.faceless.pdf2.viewer2;

import javax.swing.*;
import javax.swing.filechooser.FileFilter;
import java.awt.*;
import java.awt.event.*;
import org.faceless.pdf2.*;
import org.faceless.pdf2.viewer2.feature.*;
import org.faceless.pdf2.viewer2.util.LongRunningTask;
import java.util.*;
import java.io.*;

/**
 * A type of {@link ViewerFeature} which allows PDF's to be saved in a variety of formats.
 * It's chiefly used with the {@link Save} widget, although it can be
 * used in other contexts if necessary.
 * <p><i>This code is copyright the Big Faceless Organization. You're welcome to use, modify and distribute it in any form in your own projects, provided those projects continue to make use of the Big Faceless PDF library.</i></p>
 * @since 2.10.2
 */
public abstract class Exporter extends ViewerFeature {

    /**
     * Create a new Exporter
     * @param name the name of the feature
     */
    public Exporter(String name) {
        super(name);
    }

    /**
     * Get a FileFilter that matches the Files output by this Exporter
     */
    public abstract FileFilter getFileFilter();

    /**
     * Return the suffix of files normally output by this Exporter, such
     * as "pdf", "tif", "jpg" etc.
     */
    public abstract String getFileSuffix();

    /**
     * Return true if this Exporter should be available for this PDF.
     * The default implementation always returns true.
     * @since 2.10.3
     */
    public boolean isEnabled(PDF pdf) {
        return true;
    }

    /**
     * Return a new {@link ExporterTask} that would save a PDF
     * @param panel the DocumentPanel this PDF is being saved from - may be null
     * @param pdf the PDF being saves (not null)
     * @param component the JComponent returned by {@link ExporterTask#getComponent}
     * @param out the OutputStream to write the PDF to
     */
    public abstract ExporterTask getExporter(DocumentPanel panel, PDF pdf, JComponent component, OutputStream out);

    /**
     * This class is a {@link LongRunningTask} that can be run to save a PDF to
     * an OutputStream. Subclasses need to implement the {@link #savePDF} method,
     * which should save the PDF to the OutputStream supplied in the {@link Exporter#getExporter}
     * method.
     * <p><i>This code is copyright the Big Faceless Organization. You're welcome to use, modify and distribute it in any form in your own projects, provided those projects continue to make use of the Big Faceless PDF library.</i></p>
     * @since 2.10.2
     */
    public abstract class ExporterTask extends LongRunningTask {
        public void run() throws IOException {
            savePDF();
            completed();
        }

        /**
         * Save the PDF to the OutputStream
         */
        public abstract void savePDF() throws IOException;

        /**
         * Called when the save has completed - by default, a no-op
         * @since 2.11.2
         */
        public void completed() {
        }
    }

    /**
     * Return a JComponent which prompts the user for additional information after
     * the initial save dialog. An example might be when saving to a bitmap format -
     * this component could prompt for image resolution and so on. If this method
     * returns <code>null</code> (the default), then no additional component will
     * be displayed on save.
     */
    public JComponent getComponent() {
        return null;
    }

    /**
     * Given the component returned by {@link #getComponent}, return <code>null</code>
     * if the values are valid or an error message if they're invalid.
     * @param comp the Component returned by {@link #getComponent}
     */
    public String validateComponent(JComponent comp) {
        return null;
    }
}
