// $Id: SearchField.java 14034 2011-10-13 16:44:21Z mike $

package org.faceless.pdf2.viewer2.feature;

import org.faceless.pdf2.viewer2.*;
import org.faceless.pdf2.*;
import javax.swing.*;
import java.awt.geom.*;
import java.awt.*;
import java.util.*;
import java.awt.event.*;

/**
 * Create a widget that displays a Search field in the Toolbar. When activated, this widget
 * will select or create a {@link SearchPanel.Results} and display the search results.
 *
 * <span class="featurename">The name of this feature is <span class="featureactualname">SearchField</span></span>
 * <p><i>This code is copyright the Big Faceless Organization. You're welcome to use, modify and distribute it in any form in your own projects, provided those projects continue to make use of the Big Faceless PDF library.</i></p>
 * @since 2.8
 */
public class SearchField extends ViewerWidget
{
    private SearchPanel.Field field;
    private SearchPanel.Results createdResults;

    public SearchField() {
        super("SearchField");

        field = new SearchPanel.Field(10);
        field.setFont(null);
        field.setEditable(true);
        field.setEnabled(false);
        setComponent("Search", field);
        field.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent event) {
                field.transferFocus();
                final DocumentPanel docpanel = getViewer().getActiveDocumentPanel();
                SearchPanel.Results results = null;
                // 1. Try to find Results panel in existing side panels.
                for (Iterator i = docpanel.getSidePanels().iterator();results==null && i.hasNext();) {
                    SidePanel sidepanel = (SidePanel)i.next();
                    if (sidepanel instanceof SearchPanel.Results) {
                        results = (SearchPanel.Results)sidepanel;
                    }
                }
                if (results==null) {        // Not found - create and make sure when we hit ESC, we delete
                    final SidePanel previouspanel = docpanel.getSelectedSidePanel();
                    results = new SearchPanel.Results();
                    docpanel.addSidePanel(results);
                    docpanel.setSelectedSidePanel(results);
                    createdResults = results;
                    field.getKeymap().addActionForKeyStroke(KeyStroke.getKeyStroke("ESCAPE"), new AbstractAction() {
                        public void actionPerformed(ActionEvent event) {
                            createdResults.cancel();
                            field.setText("");
                            if (docpanel.getSelectedSidePanel()==createdResults) {
                                docpanel.setSelectedSidePanel(previouspanel);
                            }
                            docpanel.removeSidePanel(createdResults);
                            field.getKeymap().removeKeyStrokeBinding(KeyStroke.getKeyStroke("ESCAPE"));
                        }
                    });
                } else {                    // Found - just make sure when we hit ESC we cancel
                    if (results!=createdResults) {
                        final SearchPanel.Results fresults = results;
                        field.getKeymap().addActionForKeyStroke(KeyStroke.getKeyStroke("ESCAPE"), new AbstractAction() {
                            public void actionPerformed(ActionEvent event) {
                                fresults.cancel();
                                field.setText("");
                                field.getKeymap().removeKeyStrokeBinding(KeyStroke.getKeyStroke("ESCAPE"));
                            }
                        });
                    }
                }
                results.addChangeListener(field);
                docpanel.setSelectedSidePanel(results);
                results.search(field.getText());
            }
        });
    }

    public void initialize(PDFViewer viewer) {
        super.initialize(viewer);
        SearchPanel panel = (SearchPanel)viewer.getFeature(SearchPanel.class);
        if (panel!=null) {      // If there is a SearchPanel factory, remove its search field. Don't need two.
            panel.setCreateSearchField(false);
        }
    }
}
